from distutils.core import setup

setup(
        name = 'chen_nester_1',
        version = '1.1.2',
        py_modules = ['chen_nester_1'],
        author = 'ryan.chen',
        author_email = '75730263@qq.com',
        url = 'http://www.headfirstlabs.com',
        description = 'A simple printer of nested lists',
    )
